@@ -31,7 +31,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.38';
+our $VERSION = '2.39';
 
 =head1 SYNOPSIS
 
@@ -531,31 +531,32 @@ has 'slurmfile' => (
     },
 );
 
-=head2 jobref
+#=head2 jobref
 
-Array of arrays details slurmjob id. Index -1 is the most recent job submissisions, and there will be an index -2 if there are any job dependencies
+#Array of arrays details slurmjob id. Index -1 is the most recent job submissisions, and there will be an index -2 if there are any job dependencies
 
-=cut
+#=cut
 
-has 'jobref' => (
-    traits  => ['NoGetopt'],
-    is => 'rw',
-    isa => 'ArrayRef',
-    default => sub { [ [] ]  },
-);
+#has 'jobref' => (
+    #traits  => ['NoGetopt'],
+    #is => 'rw',
+    #isa => 'ArrayRef',
+    #default => sub { [ [] ]  },
+#);
 
-=head2 wait
+## Added this HPC::Runner base class
+#=head2 wait
 
-Boolean value indicates any job dependencies
+#Boolean value indicates any job dependencies
 
-=cut
+#=cut
 
-has 'wait' => (
-    traits  => ['NoGetopt'],
-    is => 'rw',
-    isa => 'Bool',
-    default => 0,
-);
+#has 'wait' => (
+    #traits  => ['NoGetopt'],
+    #is => 'rw',
+    #isa => 'Bool',
+    #default => 0,
+#);
 
 =head1 SUBROUTINES/METHODS
 
